#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_SQRT_1O_5_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_SQRT_1O_5_HPP_INCLUDED

#include <boost/simd/constant/include/constants/sqrt_1o_5.hpp>

#endif
